==> haskell-prettyprinter-1.2.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.2.1
id: prettyprinter-1.2.1-8GKo8hGt2bB40TGsLxxCXn
key: prettyprinter-1.2.1-8GKo8hGt2bB40TGsLxxCXn
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: b62aaf3751c4db8d6f8dee59599ee292
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-1.2.1
hs-libraries: HSprettyprinter-1.2.1-8GKo8hGt2bB40TGsLxxCXn
depends:
    base-4.11.1.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.2.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.2.1
id: prettyprinter-1.2.1-AQ7onoQgGnsFEEPn37paqa
key: prettyprinter-1.2.1-AQ7onoQgGnsFEEPn37paqa
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: 1f292ee3fe29317b46f5946763b487fb
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-1.2.1
hs-libraries: HSprettyprinter-1.2.1-AQ7onoQgGnsFEEPn37paqa
depends:
    base-4.11.1.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
